from __future__ import absolute_import
from . import utils
from . import paths
from . import setup_hd_glio

print("\n########################")
print("If you are using hd-bet, please cite the following papers:\n")
print("Kickingereder P, Isensee F, Tursunova I, Petersen J, Neuberger U, Bonekamp D, Brugnara G, Schell M, Kessler T, "
      "Foltyn M, Harting I, Sahm F, Prager M, Nowosielski M, Wick A, Nolden M, Radbruch A, Debus J, Schlemmer HP, "
      "Heiland S, Platten M, von Deimling A, van den Bent MJ, Gorlia T, Wick W, Bendszus M, Maier-Hein KH. Automated "
      "quantitative tumour response assessment of MRI in neuro-oncology with artificial neural networks: a "
      "multicentre, retrospective study. Lancet Oncol. 2019 May;20(5):728-740. "
      "https://doi.org/10.1016/S1470-2045(19)30098-1\n")
print("Isensee, Fabian, et al. \"nnU-Net: Breaking the Spell on Successful Medical Image Segmentation.\" "
      "arXiv preprint arXiv:1904.08128 (2019). (https://arxiv.org/abs/1904.08128)\n")



from urllib.request import urlopen
from batchgenerators.utilities.file_and_folder_operations import *
from hd_glio.paths import folder_with_parameter_files
import shutil
import zipfile


def maybe_download_weights():
    if not isfile(join(folder_with_parameter_files, 'fold_0', "model_best.model")) or not \
            isfile(join(folder_with_parameter_files, 'fold_0', "model_best.model.pkl")):
        if isdir(folder_with_parameter_files):
            shutil.rmtree(folder_with_parameter_files)
        maybe_mkdir_p(folder_with_parameter_files)

        out_filename = join(folder_with_parameter_files, "parameters.zip")

        if not os.path.isfile(out_filename):
            url = "https://zenodo.org/record/3380272/files/hd_glio_params.zip?download=1"
            print("Downloading", url, "...")
            data = urlopen(url).read()
            with open(out_filename, 'wb') as f:
                f.write(data)

        zipfile.ZipFile(out_filename).extractall(path=folder_with_parameter_files)
        os.remove(out_filename)




from setuptools import setup


setup(name='hd_glio',
      version='1.2',
      packages=["hd_glio"],
      description='Tool for brain tumor segmentation. This is the result of a joint project between the Department of '
                  'Neuroradiology at the Heidelberg University Hospital and the Division of Medical Image Computing at '
                  'the German Cancer Research Center (DKFZ). See readme.md for more information',
      url='https://github.com/MIC-DKFZ/hd_glio',
      python_requires='>=3.5',
      author='Fabian Isensee',
      author_email='f.isensee@dkfz.de',
      license='Apache 2.0',
      zip_safe=False,
      install_requires=[
          'torch',
          'numpy',
          'scikit-image',
          'SimpleITK',
          'batchgenerators'
      ],
      scripts=['hd_glio/hd_glio_predict',
               'hd_glio/hd_glio_predict_folder'],
      classifiers=[
          'Intended Audience :: Science/Research',
          'Programming Language :: Python',
          'Topic :: Scientific/Engineering',
          'Operating System :: Unix'
      ]
      )

